# Attribution

This project is an independent open-source implementation informed by:

- "TurboQuant: Online Vector Quantization with Near-optimal Distortion Rate"
- PolarQuant
- QJL
- DRIVE
- QuaRot

This repository is not affiliated with Google Research.
